@@ -16,10 +16,7 @@ class CRMLeadService(Component):
 
     def create(self, **params):
         params = self._prepare_create(params)
-        # tracking_disable=True in context is needed
-        # to avoid to send a mail in CRMLead creation
-        sr = self.env["crm.lead"].with_context(
-            tracking_disable=True).create(params)
+        sr = self.env["crm.lead"].sudo().create(params)
         return self._to_dict(sr)
 
     def _validator_create(self):
@@ -34,29 +31,25 @@ class CRMLeadService(Component):
             "id": crm_lead.id
         }
 
-    def _prepare_address(self, address):
-        return "{} {} {} {} {} {}".format(
-            address["street"],
-            address.get("street2"),
-            address["zip_code"],
-            address["city"],
-            address["state"],
-            address["country"]
-        )
-
     def _prepare_create(self, params):
         return {
+            "is_telecom": True,
             "name": params.get("partner_name"),
             "partner_name": params.get("partner_name"),
-            "dni": params.get("dni"),
+            # TODO: dni is called vat in vertical telecom
+            "vat": params.get("dni"),
             "birth_date": params.get("birth_date"),
             "phone": params.get("phone"),
             "email_from": params.get("email_from"),
-            "street": self._prepare_address(params.get("street")),
-            "invoice_address": self._prepare_address(params.get("invoice_address")),
+            "street": params.get("street")["street"],
+            "city": 'Oñati',
+            "zip": '20560',
+            "state_id": self.env.ref("base.state_es_ss").id,
+            "invoice_address": params.get("invoice_address")["street"],
             "portability_number": params.get("portability_number"),
             "iban": params.get("iban"),
             "language": params.get("language"),
             "policy_accepted": params.get("policy_accepted"),
-            "tag_ids": [(6, 0, params.get("tag_ids"))],
+            "tag_ids": [(6, 0, params.get("tag_ids", []))],
+            "description": params.get("description"),
         }
